@@ -2,12 +2,13 @@
 //
 // spritemisc
 //
-// Copyright (c)  Martin R. Jones 1999
+// Copyright Martin R. Jones 1999 <mjones@kde.org>
 //
 
-#include <kapplication.h>
 #include "spritemisc.h"
 
+#include <krandom.h>
+
 QSize SpriteRange::mFieldSize;
 
 SpriteRange::SpriteRange(const QString &str)
@@ -21,7 +22,7 @@ int SpriteRange::random() const
 
     if (mMax != mMin)
     {
-        val = (KApplication::random()%(mMax-mMin)) + mMin;
+        val = (KRandom::random()%(mMax-mMin)) + mMin;
     }
 
     return val;
@@ -29,7 +30,7 @@ int SpriteRange::random() const
 
 void SpriteRange::set(const QString &str)
 {
-    int r = str.find("..");
+    int r = str.indexOf("..");
 
     if (r > 0)
     {
